==> uui-icon-registry-0.0.1.tgz: package/lib/index.js <==
import { LitElement, html } from 'lit';
import { property } from 'lit/decorators.js';
import { UUIIconRequestEvent } from '@umbraco-ui/uui-icon/lib/UUIIconRequestEvent';
import { defineElement } from '@umbraco-ui/uui-base/lib/registration';

class UUIIconHost {
  constructor(svg) {
    this.promise = new Promise((resolveMethod, rejectMethod) => {
      this.resolve = resolveMethod;
      this.reject = rejectMethod;
    });
    if (svg) {
      this.resolve(svg);
    }
  }
  set svg(svg) {
    this.resolve(svg);
  }
}

class UUIIconRegistry {
  constructor() {
    this.icons = {};
    this._onIconRequest = (event) => {
      const icon = this.getIcon(event.detail.iconName);
      if (icon !== null) {
        event.acceptRequest(icon);
      }
    };
  }
  attach(element) {
    element.addEventListener(UUIIconRequestEvent.ICON_REQUEST, this._onIconRequest);
  }
  detach(element) {
    element.removeEventListener(UUIIconRequestEvent.ICON_REQUEST, this._onIconRequest);
  }
  defineIcon(iconName, svgString) {
    if (this.icons[iconName]) {
      this.icons[iconName].svg = svgString;
      return;
    }
    this.icons[iconName] = new UUIIconHost(svgString);
  }
  getIcon(iconName) {
    if (!!this.icons[iconName] || this.acceptIcon(iconName)) {
      return this.icons[iconName].promise;
    }
    return null;
  }
  provideIcon(iconName) {
    return this.icons[iconName] = new UUIIconHost();
  }
  acceptIcon(iconName) {
    return false;
  }
  getIconNames() {
    return Object.keys(this.icons);
  }
}

var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __decorateClass = (decorators, target, key, kind) => {
  var result = kind > 1 ? void 0 : kind ? __getOwnPropDesc(target, key) : target;
  for (var i = decorators.length - 1, decorator; i >= 0; i--)
    if (decorator = decorators[i])
      result = (kind ? decorator(target, key, result) : decorator(result)) || result;
  if (kind && result)
    __defProp(target, key, result);
  return result;
};
class UUIIconRegistryElement extends LitElement {
  constructor() {
    super(...arguments);
    this._icons = {};
    this._registry = new UUIIconRegistry();
  }
  get icons() {
    return this._icons;
  }
  set icons(icons) {
    this._icons = icons;
    if (this._registry) {
      this.defineIconsInRegistry();
    }
  }
  defineIconsInRegistry() {
    Object.entries(this._icons).forEach(([key, value]) => this._registry.defineIcon(key, value));
  }
  get registry() {
    return this._registry;
  }
  set registry(newRegistry) {
    if (this.shadowRoot) {
      if (this.registry) {
        this.registry.detach(this);
      }
      newRegistry.attach(this);
    }
    this._registry = newRegistry;
  }
  connectedCallback() {
    super.connectedCallback();
    this.registry.attach(this);
  }
  disconnectedCallback() {
    super.disconnectedCallback();
    this.registry.detach(this);
  }
  render() {
    return html`<slot></slot>`;
  }
}
__decorateClass([
  property({ attribute: false })
], UUIIconRegistryElement.prototype, "_icons", 2);

defineElement("uui-icon-registry", UUIIconRegistryElement);

==> uui-icon-registry-0.1.1.tgz: package/lib/index.js <==
import { LitElement, html } from 'lit';
import { defineElement } from '@umbraco-ui/uui-base/lib/registration';
import { property } from 'lit/decorators.js';
import { UUIIconRequestEvent } from '@umbraco-ui/uui-icon/lib';

class UUIIconHost {
  constructor(svg) {
    this.promise = new Promise((resolveMethod, rejectMethod) => {
      this.resolve = resolveMethod;
      this.reject = rejectMethod;
    });
    if (svg) {
      this.resolve(svg);
    }
  }
  set svg(svg) {
    this.resolve(svg);
  }
}

class UUIIconRegistry {
  constructor() {
    this.icons = {};
    this._onIconRequest = (event) => {
      const icon = this.getIcon(event.detail.iconName);
      if (icon !== null) {
        event.acceptRequest(icon);
      }
    };
  }
  attach(element) {
    element.addEventListener(UUIIconRequestEvent.ICON_REQUEST, this._onIconRequest);
  }
  detach(element) {
    element.removeEventListener(UUIIconRequestEvent.ICON_REQUEST, this._onIconRequest);
  }
  defineIcon(iconName, svgString) {
    if (this.icons[iconName]) {
      this.icons[iconName].svg = svgString;
      return;
    }
    this.icons[iconName] = new UUIIconHost(svgString);
  }
  getIcon(iconName) {
    if (!!this.icons[iconName] || this.acceptIcon(iconName)) {
      return this.icons[iconName].promise;
    }
    return null;
  }
  provideIcon(iconName) {
    return this.icons[iconName] = new UUIIconHost();
  }
  acceptIcon(iconName) {
    return false;
  }
  getIconNames() {
    return Object.keys(this.icons);
  }
}

var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __decorateClass = (decorators, target, key, kind) => {
  var result = kind > 1 ? void 0 : kind ? __getOwnPropDesc(target, key) : target;
  for (var i = decorators.length - 1, decorator; i >= 0; i--)
    if (decorator = decorators[i])
      result = (kind ? decorator(target, key, result) : decorator(result)) || result;
  if (kind && result)
    __defProp(target, key, result);
  return result;
};
let UUIIconRegistryElement = class extends LitElement {
  constructor() {
    super();
    this._icons = {};
    this._registry = new UUIIconRegistry();
    this._registry.attach(this);
  }
  get icons() {
    return this._icons;
  }
  set icons(icons) {
    this._icons = icons;
    if (this._registry) {
      Object.entries(this._icons).forEach(([key, value]) => this._registry.defineIcon(key, value));
    }
  }
  get registry() {
    return this._registry;
  }
  set registry(newRegistry) {
    if (this.registry) {
      this.registry.detach(this);
    }
    newRegistry.attach(this);
    this._registry = newRegistry;
  }
  render() {
    return html`<slot></slot>`;
  }
};
__decorateClass([
  property({ attribute: false })
], UUIIconRegistryElement.prototype, "_icons", 2);
UUIIconRegistryElement = __decorateClass([
  defineElement("uui-icon-registry")
], UUIIconRegistryElement);

export { UUIIconHost, UUIIconRegistry, UUIIconRegistryElement };
